summaryrefslogtreecommitdiffstats
path: root/libtdepim
diff options
context:
space:
mode:
Diffstat (limited to 'libtdepim')
-rw-r--r--libtdepim/addresseeview.cpp110
-rw-r--r--libtdepim/addressesdialog.cpp2
-rw-r--r--libtdepim/addresspicker.ui4
-rw-r--r--libtdepim/broadcaststatus.cpp42
-rw-r--r--libtdepim/broadcaststatus.h12
-rw-r--r--libtdepim/clicklineedit.cpp8
-rw-r--r--libtdepim/completionordereditor.cpp6
-rw-r--r--libtdepim/csshelper.cpp46
-rw-r--r--libtdepim/embeddedurlpage.cpp2
-rw-r--r--libtdepim/htmldiffalgodisplay.cpp22
-rw-r--r--libtdepim/kaddrbook.cpp6
-rw-r--r--libtdepim/kcmdesignerfields.cpp22
-rw-r--r--libtdepim/kfileio.cpp54
-rw-r--r--libtdepim/kfoldertree.cpp6
-rw-r--r--libtdepim/kimportdialog.cpp2
-rw-r--r--libtdepim/kincidencechooser.cpp4
-rw-r--r--libtdepim/komposer/core/pluginmanager.cpp2
-rw-r--r--libtdepim/komposer/plugins/default/defaulteditor.cpp12
-rw-r--r--libtdepim/komposer/plugins/default/defaulteditorui.rc2
-rw-r--r--libtdepim/kpixmapregionselectorwidget.cpp6
-rw-r--r--libtdepim/kregexp3.cpp10
-rw-r--r--libtdepim/krsqueezedtextlabel.cpp4
-rw-r--r--libtdepim/kscoring.cpp2
-rw-r--r--libtdepim/ksubscription.cpp4
-rw-r--r--libtdepim/ldapclient.cpp56
-rw-r--r--libtdepim/ldapsearchdialog.cpp18
-rw-r--r--libtdepim/linklocator.cpp6
-rw-r--r--libtdepim/overlaywidget.h2
-rw-r--r--libtdepim/progressdialog.cpp4
-rw-r--r--libtdepim/progressdialog.h2
-rw-r--r--libtdepim/progressmanager.cpp6
-rw-r--r--libtdepim/progressmanager.h10
-rw-r--r--libtdepim/qutf7codec.cpp2
-rw-r--r--libtdepim/qutf7codec.h2
-rw-r--r--libtdepim/qutf7codecplugin.cpp2
-rw-r--r--libtdepim/sendsmsdialog.cpp8
36 files changed, 254 insertions, 254 deletions
diff --git a/libtdepim/addressesdialog.cpp b/libtdepim/addressesdialog.cpp
index a8d993bf8..2a3cca2f4 100644
--- a/libtdepim/addressesdialog.cpp
+++ b/libtdepim/addressesdialog.cpp
@@ -912,7 +912,7 @@ AddressesDialog::saveAs()
KMessageBox::information( 0,
i18n( "<qt>Distribution list with the given name <b>%1</b> "
"already exists. Please select a different name.</qt>" )
- .tqarg( name ) );
+ .arg( name ) );
return;
}
diff --git a/libtdepim/addresspicker.ui b/libtdepim/addresspicker.ui
index 9dd43bc0a..a11680ff8 100644
--- a/libtdepim/addresspicker.ui
+++ b/libtdepim/addresspicker.ui
@@ -181,7 +181,7 @@
<property name="text">
<string>&amp;Selected Addresses</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignCenter</set>
</property>
<property name="buddy" stdset="0">
@@ -200,7 +200,7 @@
<property name="text">
<string>&amp;Address Book</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignCenter</set>
</property>
<property name="buddy" stdset="0">
diff --git a/libtdepim/broadcaststatus.cpp b/libtdepim/broadcaststatus.cpp
index f87503f97..c48d7f414 100644
--- a/libtdepim/broadcaststatus.cpp
+++ b/libtdepim/broadcaststatus.cpp
@@ -46,23 +46,23 @@ BroadcastStatus::~BroadcastStatus()
instance_ = 0;
}
-void BroadcastStatus::seStatusMsg( const TQString& message )
+void BroadcastStatus::setStatusMsg( const TQString& message )
{
mStatusMsg = message;
if( !mTransientActive )
emit statusMsg( message );
}
-void BroadcastStatus::seStatusMsgWithTimestamp( const TQString& message )
+void BroadcastStatus::setStatusMsgWithTimestamp( const TQString& message )
{
KLocale* locale = KGlobal::locale();
- seStatusMsg( i18n( "%1 is a time, %2 is a status message", "[%1] %2" )
- .tqarg( locale->formatTime( TQTime::currentTime(),
+ setStatusMsg( i18n( "%1 is a time, %2 is a status message", "[%1] %2" )
+ .arg( locale->formatTime( TQTime::currentTime(),
true /* with seconds */ ) )
- .tqarg( message ) );
+ .arg( message ) );
}
-void BroadcastStatus::seStatusMsgTransmissionCompleted( int numMessages,
+void BroadcastStatus::setStatusMsgTransmissionCompleted( int numMessages,
int numBytes,
int numBytesRead,
int numBytesToRead,
@@ -78,13 +78,13 @@ void BroadcastStatus::seStatusMsgTransmissionCompleted( int numMessages,
"Transmission complete. %n new messages in %1 KB "
"(%2 KB remaining on the server).",
numMessages )
- .tqarg( numBytesRead / 1024 )
- .tqarg( numBytes / 1024 );
+ .arg( numBytesRead / 1024 )
+ .arg( numBytes / 1024 );
else
statusMsg = i18n( "Transmission complete. %n message in %1 KB.",
"Transmission complete. %n messages in %1 KB.",
numMessages )
- .tqarg( numBytesRead / 1024 );
+ .arg( numBytesRead / 1024 );
}
else
statusMsg = i18n( "Transmission complete. %n new message.",
@@ -94,12 +94,12 @@ void BroadcastStatus::seStatusMsgTransmissionCompleted( int numMessages,
else
statusMsg = i18n( "Transmission complete. No new messages." );
- seStatusMsgWithTimestamp( statusMsg );
+ setStatusMsgWithTimestamp( statusMsg );
if ( item )
- item->seStatus( statusMsg );
+ item->setStatus( statusMsg );
}
-void BroadcastStatus::seStatusMsgTransmissionCompleted( const TQString& account,
+void BroadcastStatus::setStatusMsgTransmissionCompleted( const TQString& account,
int numMessages,
int numBytes,
int numBytesRead,
@@ -118,17 +118,17 @@ void BroadcastStatus::seStatusMsgTransmissionCompleted( const TQString& account,
"%n new messages in %1 KB "
"(%2 KB remaining on the server).",
numMessages )
- .tqarg( numBytesRead / 1024 )
- .tqarg( numBytes / 1024 )
- .tqarg( account );
+ .arg( numBytesRead / 1024 )
+ .arg( numBytes / 1024 )
+ .arg( account );
else
statusMsg = i18n( "Transmission for account %2 complete. "
"%n message in %1 KB.",
"Transmission for account %2 complete. "
"%n messages in %1 KB.",
numMessages )
- .tqarg( numBytesRead / 1024 )
- .tqarg( account );
+ .arg( numBytesRead / 1024 )
+ .arg( account );
}
else
statusMsg = i18n( "Transmission for account %1 complete. "
@@ -136,15 +136,15 @@ void BroadcastStatus::seStatusMsgTransmissionCompleted( const TQString& account,
"Transmission for account %1 complete. "
"%n new messages.",
numMessages )
- .tqarg( account );
+ .arg( account );
}
else
statusMsg = i18n( "Transmission for account %1 complete. No new messages.")
- .tqarg( account );
+ .arg( account );
- seStatusMsgWithTimestamp( statusMsg );
+ setStatusMsgWithTimestamp( statusMsg );
if ( item )
- item->seStatus( statusMsg );
+ item->setStatus( statusMsg );
}
void BroadcastStatus::setTransienStatusMsg( const TQString& msg )
diff --git a/libtdepim/clicklineedit.cpp b/libtdepim/clicklineedit.cpp
index 28e66a0ba..352b26795 100644
--- a/libtdepim/clicklineedit.cpp
+++ b/libtdepim/clicklineedit.cpp
@@ -39,13 +39,13 @@ ClickLineEdit::~ClickLineEdit() {}
void ClickLineEdit::setClickMessage( const TQString &msg )
{
mClickMessage = msg;
- tqrepaint();
+ repaint();
}
void ClickLineEdit::setText( const TQString &txt )
{
mDrawClickMsg = txt.isEmpty();
- tqrepaint();
+ repaint();
KLineEdit::setText( txt );
}
@@ -67,7 +67,7 @@ void ClickLineEdit::focusInEvent( TQFocusEvent *ev )
if ( mDrawClickMsg == true )
{
mDrawClickMsg = false;
- tqrepaint();
+ repaint();
}
TQLineEdit::focusInEvent( ev );
}
@@ -77,7 +77,7 @@ void ClickLineEdit::focusOutEvent( TQFocusEvent *ev )
if ( text().isEmpty() )
{
mDrawClickMsg = true;
- tqrepaint();
+ repaint();
}
TQLineEdit::focusOutEvent( ev );
}
diff --git a/libtdepim/completionordereditor.cpp b/libtdepim/completionordereditor.cpp
index 0ee36a290..68339f9e1 100644
--- a/libtdepim/completionordereditor.cpp
+++ b/libtdepim/completionordereditor.cpp
@@ -88,7 +88,7 @@ class LDAPCompletionItem : public CompletionItem
{
public:
LDAPCompletionItem( LdapClient* ldapClient ) : mLdapClient( ldapClient ) {}
- virtual TQString label() const { return i18n( "LDAP server %1" ).tqarg( mLdapClient->server().host() ); }
+ virtual TQString label() const { return i18n( "LDAP server %1" ).arg( mLdapClient->server().host() ); }
virtual int completionWeight() const { return mLdapClient->completionWeight(); }
virtual void save( CompletionOrderEditor* );
protected:
@@ -102,7 +102,7 @@ void LDAPCompletionItem::save( CompletionOrderEditor* )
{
KConfig * config = LdapSearch::config();
config->setGroup( "LDAP" );
- config->writeEntry( TQString( "SelectedCompletionWeight%1" ).tqarg( mLdapClient->clientNumber() ),
+ config->writeEntry( TQString( "SelectedCompletionWeight%1" ).arg( mLdapClient->clientNumber() ),
mWeight );
config->sync();
}
@@ -141,7 +141,7 @@ public:
KABCImapSubResCompletionItem( ResourceABC* resource, const TQString& subResource )
: mResource( resource ), mSubResource( subResource ), mWeight( completionWeight() ) {}
virtual TQString label() const {
- return TQString( "%1 %2" ).tqarg( mResource->resourceName() ).tqarg( mResource->subresourceLabel( mSubResource ) );
+ return TQString( "%1 %2" ).arg( mResource->resourceName() ).arg( mResource->subresourceLabel( mSubResource ) );
}
virtual int completionWeight() const {
return mResource->subresourceCompletionWeight( mSubResource );
diff --git a/libtdepim/csshelper.cpp b/libtdepim/csshelper.cpp
index 379eb8ea0..a95daad6f 100644
--- a/libtdepim/csshelper.cpp
+++ b/libtdepim/csshelper.cpp
@@ -184,9 +184,9 @@ namespace KPIM {
? level % numQuoteLevels + 1
: kMin( level + 1, numQuoteLevels ) ;
if ( level >= numQuoteLevels )
- return TQString( "<div class=\"deepquotelevel%1\">" ).tqarg( effectiveLevel );
+ return TQString( "<div class=\"deepquotelevel%1\">" ).arg( effectiveLevel );
else
- return TQString( "<div class=\"quotelevel%1\">" ).tqarg( effectiveLevel );
+ return TQString( "<div class=\"quotelevel%1\">" ).arg( effectiveLevel );
}
TQString CSSHelper::nonQuotedFontTag() const {
@@ -214,8 +214,8 @@ namespace KPIM {
TQString CSSHelper::printCssDefinitions( bool fixed ) const {
const TQString headerFont = TQString( " font-family: \"%1\" ! important;\n"
" font-size: %2pt ! important;\n" )
- .tqarg( mPrintFont.family() )
- .tqarg( mPrintFont.pointSize() );
+ .arg( mPrintFont.family() )
+ .arg( mPrintFont.pointSize() );
const TQColorGroup & cg = TQApplication::tqpalette().active();
const TQFont printFont = bodyFont( fixed, true /* print */ );
@@ -234,7 +234,7 @@ namespace KPIM {
" color: #000000 ! important;\n"
" background-color: #ffffff ! important\n"
"}\n\n" )
- .tqarg( printFont.family(),
+ .arg( printFont.family(),
TQString::number( printFont.pointSize() ) )
+
TQString( "tr.textAtmH,\n"
@@ -288,7 +288,7 @@ namespace KPIM {
" display:none ! important;\n"
"}\n\n"
)
- .tqarg( headerFont,
+ .arg( headerFont,
cg.background().name(),
cg.foreground().name() )
+ quoteCSS;
@@ -300,13 +300,13 @@ namespace KPIM {
const TQString linkColor = mLinkColor.name();
const TQString headerFont = TQString(" font-family: \"%1\" ! important;\n"
" font-size: %2px ! important;\n")
- .tqarg( mBodyFont.family() )
- .tqarg( pointsToPixel( helper->mMetrics, mBodyFont.pointSize() ) );
+ .arg( mBodyFont.family() )
+ .arg( pointsToPixel( helper->mMetrics, mBodyFont.pointSize() ) );
const TQString background = ( mBackingPixmapOn
? TQString( " background-image:url(file://%1) ! important;\n" )
- .tqarg( mBackingPixmapStr )
+ .arg( mBackingPixmapStr )
: TQString( " background-color: %1 ! important;\n" )
- .tqarg( bgColor ) );
+ .arg( bgColor ) );
const TQString bodyFontSize = TQString::number( pointsToPixel( helper->mMetrics, fontSize( fixed ) ) ) + "px" ;
const TQColorGroup & cg = TQApplication::tqpalette().active();
@@ -322,7 +322,7 @@ namespace KPIM {
for ( int i = 0 ; i < 3 ; ++i ) {
quoteCSS += TQString( "div.quotelevel%1 {\n"
" color: %2 ! important;\n" )
- .tqarg( TQString::number(i+1), mQuoteColor[i].name() );
+ .arg( TQString::number(i+1), mQuoteColor[i].name() );
if ( mQuoteFont[i].italic() )
quoteCSS += " font-style: italic ! important;\n";
if ( mQuoteFont[i].bold() )
@@ -337,7 +337,7 @@ namespace KPIM {
for ( int i = 0 ; i < 3 ; ++i ) {
quoteCSS += TQString( "div.deepquotelevel%1 {\n"
" color: %2 ! important;\n" )
- .tqarg( TQString::number(i+1), mQuoteColor[i].name() );
+ .arg( TQString::number(i+1), mQuoteColor[i].name() );
if ( mQuoteFont[i].italic() )
quoteCSS += " font-style: italic ! important;\n";
if ( mQuoteFont[i].bold() )
@@ -354,7 +354,7 @@ namespace KPIM {
" color: %3 ! important;\n"
"%4"
"}\n\n" )
- .tqarg( bodyFont( fixed ).family(),
+ .arg( bodyFont( fixed ).family(),
bodyFontSize,
fgColor,
background )
@@ -392,7 +392,7 @@ namespace KPIM {
"tr.rfc822H {\n"
"%4"
"}\n\n" )
- .tqarg( linkColor, fgColor, bgColor, headerFont )
+ .arg( linkColor, fgColor, bgColor, headerFont )
+
TQString( "table.encr {\n"
" background-color: %1 ! important;\n"
@@ -404,7 +404,7 @@ namespace KPIM {
"}\n\n"
"tr.encrB { background-color: %4 ! important; }\n\n" )
- .tqarg( cPgpEncrF.name(),
+ .arg( cPgpEncrF.name(),
cPgpEncrH.name(),
headerFont,
cPgpEncrB.name() )
@@ -419,7 +419,7 @@ namespace KPIM {
"}\n\n"
"tr.signOkKeyOkB { background-color: %4 ! important; }\n\n" )
- .tqarg( cPgpOk1F.name(),
+ .arg( cPgpOk1F.name(),
cPgpOk1H.name(),
headerFont,
cPgpOk1B.name() )
@@ -434,7 +434,7 @@ namespace KPIM {
"}\n\n"
"tr.signOkKeyBadB { background-color: %4 ! important; }\n\n" )
- .tqarg( cPgpOk0F.name(),
+ .arg( cPgpOk0F.name(),
cPgpOk0H.name(),
headerFont,
cPgpOk0B.name() )
@@ -449,7 +449,7 @@ namespace KPIM {
"}\n\n"
"tr.signWarnB { background-color: %4 ! important; }\n\n" )
- .tqarg( cPgpWarnF.name(),
+ .arg( cPgpWarnF.name(),
cPgpWarnH.name(),
headerFont,
cPgpWarnB.name() )
@@ -464,7 +464,7 @@ namespace KPIM {
"}\n\n"
"tr.signErrB { background-color: %4 ! important; }\n\n" )
- .tqarg( cPgpErrF.name(),
+ .arg( cPgpErrF.name(),
cPgpErrH.name(),
headerFont,
cPgpErrB.name() )
@@ -472,7 +472,7 @@ namespace KPIM {
TQString( "div.htmlWarn {\n"
" border: 2px solid %1 ! important;\n"
"}\n\n" )
- .tqarg( cHtmlWarning.name() )
+ .arg( cHtmlWarning.name() )
+
TQString( "div.header {\n"
"%1"
@@ -519,12 +519,12 @@ namespace KPIM {
"}\n\n"
)
- .tqarg( headerFont )
- .tqarg( cg.highlight().name(),
+ .arg( headerFont )
+ .arg( cg.highlight().name(),
cg.highlightedText().name(),
cg.foreground().name(),
cg.background().name() )
- .tqarg( cg.mid().name() )
+ .arg( cg.mid().name() )
+ quoteCSS;
}
diff --git a/libtdepim/embeddedurlpage.cpp b/libtdepim/embeddedurlpage.cpp
index 3971bf367..3c32f8324 100644
--- a/libtdepim/embeddedurlpage.cpp
+++ b/libtdepim/embeddedurlpage.cpp
@@ -43,7 +43,7 @@ void EmbeddedURLPage::initGUI( const TQString &url, const TQString &/*mimetype*/
{
TQVBoxLayout *tqlayout = new TQVBoxLayout( this );
tqlayout->setAutoAdd( true );
- new TQLabel( i18n("Showing URL %1").tqarg( url ), this );
+ new TQLabel( i18n("Showing URL %1").arg( url ), this );
}
void EmbeddedURLPage::loadContents()
diff --git a/libtdepim/htmldiffalgodisplay.cpp b/libtdepim/htmldiffalgodisplay.cpp
index 726854e4e..4be6b6cde 100644
--- a/libtdepim/htmldiffalgodisplay.cpp
+++ b/libtdepim/htmldiffalgodisplay.cpp
@@ -45,13 +45,13 @@ void HTMLDiffAlgoDisplay::begin()
mText.append( "<html>" );
mText.append( TQString( "<body text=\"%1\" bgcolor=\"%2\">" )
- .tqarg( KGlobalSettings::textColor().name() )
- .tqarg( KGlobalSettings::baseColor().name() ) );
+ .arg( KGlobalSettings::textColor().name() )
+ .arg( KGlobalSettings::baseColor().name() ) );
mText.append( "<center><table>" );
mText.append( TQString( "<tr><th></th><th align=\"center\">%1</th><td> </td><th align=\"center\">%2</th></tr>" )
- .tqarg( mLeftTitle )
- .tqarg( mRightTitle ) );
+ .arg( mLeftTitle )
+ .arg( mRightTitle ) );
}
void HTMLDiffAlgoDisplay::end()
@@ -76,22 +76,22 @@ void HTMLDiffAlgoDisplay::setRightSourceTitle( const TQString &title )
void HTMLDiffAlgoDisplay::additionalLeftField( const TQString &id, const TQString &value )
{
mText.append( TQString( "<tr><td align=\"right\"><b>%1:</b></td><td bgcolor=\"#9cff83\">%2</td><td></td><td></td></tr>" )
- .tqarg( id )
- .tqarg( textToHTML( value ) ) );
+ .arg( id )
+ .arg( textToHTML( value ) ) );
}
void HTMLDiffAlgoDisplay::additionalRightField( const TQString &id, const TQString &value )
{
mText.append( TQString( "<tr><td align=\"right\"><b>%1:</b></td><td></td><td></td><td bgcolor=\"#9cff83\">%2</td></tr>" )
- .tqarg( id )
- .tqarg( textToHTML( value ) ) );
+ .arg( id )
+ .arg( textToHTML( value ) ) );
}
void HTMLDiffAlgoDisplay::conflictField( const TQString &id, const TQString &leftValue,
const TQString &rightValue )
{
mText.append( TQString( "<tr><td align=\"right\"><b>%1:</b></td><td bgcolor=\"#ff8686\">%2</td><td></td><td bgcolor=\"#ff8686\">%3</td></tr>" )
- .tqarg( id )
- .tqarg( textToHTML( leftValue ) )
- .tqarg( textToHTML( rightValue ) ) );
+ .arg( id )
+ .arg( textToHTML( leftValue ) )
+ .arg( textToHTML( rightValue ) ) );
}
diff --git a/libtdepim/kaddrbook.cpp b/libtdepim/kaddrbook.cpp
index 7854be1d1..230f4ef4b 100644
--- a/libtdepim/kaddrbook.cpp
+++ b/libtdepim/kaddrbook.cpp
@@ -74,7 +74,7 @@ void KAddrBookExternal::openEmail( const TQString &addr, TQWidget *parent ) {
//TODO: Enable the better message at the next string unfreeze
#if 0
TQString text = i18n("<qt>The email address <b>%1</b> cannot be "
- "found in your addressbook.</qt>").tqarg( email );
+ "found in your addressbook.</qt>").arg( email );
#else
TQString text = email + " " + i18n( "is not in address book" );
#endif
@@ -150,12 +150,12 @@ void KAddrBookExternal::addEmail( const TQString& addr, TQWidget *parent) {
if ( KAddrBookExternal::addAddressee( a ) ) {
TQString text = i18n("<qt>The email address <b>%1</b> was added to your "
"addressbook; you can add more information to this "
- "entry by opening the addressbook.</qt>").tqarg( addr );
+ "entry by opening the addressbook.</qt>").arg( addr );
KMessageBox::information( parent, text, TQString(), "addedtokabc" );
}
} else {
TQString text = i18n("<qt>The email address <b>%1</b> is already in your "
- "addressbook.</qt>").tqarg( addr );
+ "addressbook.</qt>").arg( addr );
KMessageBox::information( parent, text, TQString(),
"alreadyInAddressBook" );
}
diff --git a/libtdepim/kcmdesignerfields.cpp b/libtdepim/kcmdesignerfields.cpp
index 5f717b7c1..168f7f50b 100644
--- a/libtdepim/kcmdesignerfields.cpp
+++ b/libtdepim/kcmdesignerfields.cpp
@@ -176,7 +176,7 @@ void KCMDesignerFields::deleteFile()
if ( item ) {
PageItem *pageItem = static_cast<PageItem*>( item->parent() ? item->parent() : item );
if (KMessageBox::warningContinueCancel(this,
- i18n( "<qt>Do you really want to delete '<b>%1</b>'?</qt>").tqarg( pageItem->text(0) ), "", KStdGuiItem::del() )
+ i18n( "<qt>Do you really want to delete '<b>%1</b>'?</qt>").arg( pageItem->text(0) ), "", KStdGuiItem::del() )
== KMessageBox::Continue)
KIO::NetAccess::del( pageItem->path(), 0 );
}
@@ -316,10 +316,10 @@ void KCMDesignerFields::initGUI()
"<p><b>Important:</b> The widget will edit custom fields with an"
" application name of %2. To change the application name"
" to be edited, set the widget name in TQt Designer.</p></qt>" )
- .tqarg( applicationName(), applicationName() );
+ .arg( applicationName(), applicationName() );
KActiveLabel *activeLabel = new KActiveLabel(
- i18n( "<a href=\"whatsthis:%1\">How does this work?</a>" ).tqarg(cwHowto), this );
+ i18n( "<a href=\"whatsthis:%1\">How does this work?</a>" ).arg(cwHowto), this );
hbox->addWidget( activeLabel );
// ### why is this needed? Looks like a KActiveLabel bug...
@@ -360,14 +360,14 @@ void KCMDesignerFields::updatePreview( TQListViewItem *item )
"<tr><td align=\"right\"><b>%5</b></td><td>%6</td></tr>"
"<tr><td align=\"right\"><b>%7</b></td><td>%8</td></tr>"
"</table></qt>" )
- .tqarg( i18n( "Key:" ) )
- .tqarg( item->text( 0 ).replace("X_","X-") )
- .tqarg( i18n( "Type:" ) )
- .tqarg( item->text( 1 ) )
- .tqarg( i18n( "Classname:" ) )
- .tqarg( item->text( 2 ) )
- .tqarg( i18n( "Description:" ) )
- .tqarg( item->text( 3 ) );
+ .arg( i18n( "Key:" ) )
+ .arg( item->text( 0 ).replace("X_","X-") )
+ .arg( i18n( "Type:" ) )
+ .arg( item->text( 1 ) )
+ .arg( i18n( "Classname:" ) )
+ .arg( item->text( 2 ) )
+ .arg( i18n( "Description:" ) )
+ .arg( item->text( 3 ) );
mPageDetails->setText( details );
diff --git a/libtdepim/kfileio.cpp b/libtdepim/kfileio.cpp
index e167662bb..fa963e167 100644
--- a/libtdepim/kfileio.cpp
+++ b/libtdepim/kfileio.cpp
@@ -48,20 +48,20 @@ KDE_EXPORT TQCString kFileToString(const TQString &aFileName, bool aEnsureNL, bo
if (!info.exists())
{
if (aVerbose)
- msgDialog(i18n("The specified file does not exist:\n%1").tqarg(aFileName));
+ msgDialog(i18n("The specified file does not exist:\n%1").arg(aFileName));
return TQCString();
}
if (info.isDir())
{
if (aVerbose)
- msgDialog(i18n("This is a folder and not a file:\n%1").tqarg(aFileName));
+ msgDialog(i18n("This is a folder and not a file:\n%1").arg(aFileName));
return TQCString();
}
if (!info.isReadable())
{
if (aVerbose)
msgDialog(i18n("You do not have read permissions "
- "to the file:\n%1").tqarg(aFileName));
+ "to the file:\n%1").arg(aFileName));
return TQCString();
}
if (len <= 0) return TQCString();
@@ -71,13 +71,13 @@ KDE_EXPORT TQCString kFileToString(const TQString &aFileName, bool aEnsureNL, bo
if (aVerbose) switch(file.status())
{
case IO_ReadError:
- msgDialog(i18n("Could not read file:\n%1").tqarg(aFileName));
+ msgDialog(i18n("Could not read file:\n%1").arg(aFileName));
break;
case IO_OpenError:
- msgDialog(i18n("Could not open file:\n%1").tqarg(aFileName));
+ msgDialog(i18n("Could not open file:\n%1").arg(aFileName));
break;
default:
- msgDialog(i18n("Error while reading file:\n%1").tqarg(aFileName));
+ msgDialog(i18n("Error while reading file:\n%1").arg(aFileName));
}
return TQCString();
}
@@ -94,7 +94,7 @@ KDE_EXPORT TQCString kFileToString(const TQString &aFileName, bool aEnsureNL, bo
if (readLen < len)
{
TQString msg = i18n("Could only read %1 bytes of %2.")
- .tqarg(readLen).tqarg(len);
+ .arg(readLen).arg(len);
msgDialog(msg);
return TQCString();
}
@@ -120,21 +120,21 @@ TQByteArray kFileToBytes(const TQString &aFileName, bool aVerbose)
{
if (aVerbose)
msgDialog(i18n("The specified file does not exist:\n%1")
- .tqarg(aFileName));
+ .arg(aFileName));
return result;
}
if (info.isDir())
{
if (aVerbose)
msgDialog(i18n("This is a folder and not a file:\n%1")
- .tqarg(aFileName));
+ .arg(aFileName));
return result;
}
if (!info.isReadable())
{
if (aVerbose)
msgDialog(i18n("You do not have read permissions "
- "to the file:\n%1").tqarg(aFileName));
+ "to the file:\n%1").arg(aFileName));
return result;
}
if (len <= 0) return result;
@@ -144,26 +144,26 @@ TQByteArray kFileToBytes(const TQString &aFileName, bool aVerbose)
if (aVerbose) switch(file.status())
{
case IO_ReadError:
- msgDialog(i18n("Could not read file:\n%1").tqarg(aFileName));
+ msgDialog(i18n("Could not read file:\n%1").arg(aFileName));
break;
case IO_OpenError:
- msgDialog(i18n("Could not open file:\n%1").tqarg(aFileName));
+ msgDialog(i18n("Could not open file:\n%1").arg(aFileName));
break;
default:
- msgDialog(i18n("Error while reading file:\n%1").tqarg(aFileName));
+ msgDialog(i18n("Error while reading file:\n%1").arg(aFileName));
}
return result;
}
result.resize(len);
readLen = file.readBlock(result.data(), len);
- kdDebug(5300) << TQString( "len %1" ).tqarg(len) << endl;
+ kdDebug(5300) << TQString( "len %1" ).arg(len) << endl;
if (readLen < len)
{
TQString msg;
msg = i18n("Could only read %1 bytes of %2.")
- .tqarg(readLen).tqarg(len);
+ .arg(readLen).arg(len);
msgDialog(msg);
return result;
}
@@ -191,7 +191,7 @@ KDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
{
TQString str;
str = i18n("File %1 exists.\nDo you want to replace it?")
- .tqarg(aFileName);
+ .arg(aFileName);
rc = KMessageBox::warningContinueCancel(0,
str, i18n("Save to File"), i18n("&Replace"));
if (rc != KMessageBox::Continue) return FALSE;
@@ -209,7 +209,7 @@ KDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
if (!aVerbose) return FALSE;
rc = KMessageBox::warningContinueCancel(0,
i18n("Failed to make a backup copy of %1.\nContinue anyway?")
- .tqarg(aFileName),
+ .arg(aFileName),
i18n("Save to File"), KStdGuiItem::save() );
if (rc != KMessageBox::Continue) return FALSE;
}
@@ -221,14 +221,14 @@ KDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
if (aVerbose) switch(file.status())
{
case IO_WriteError:
- msgDialog(i18n("Could not write to file:\n%1").tqarg(aFileName));
+ msgDialog(i18n("Could not write to file:\n%1").arg(aFileName));
break;
case IO_OpenError:
msgDialog(i18n("Could not open file for writing:\n%1")
- .tqarg(aFileName));
+ .arg(aFileName));
break;
default:
- msgDialog(i18n("Error while writing file:\n%1").tqarg(aFileName));
+ msgDialog(i18n("Error while writing file:\n%1").arg(aFileName));
}
return FALSE;
}
@@ -238,13 +238,13 @@ KDE_EXPORT bool kBytesToFile(const char* aBuffer, int len,
if (writeLen < 0)
{
if (aVerbose)
- msgDialog(i18n("Could not write to file:\n%1").tqarg(aFileName));
+ msgDialog(i18n("Could not write to file:\n%1").arg(aFileName));
return FALSE;
}
else if (writeLen < len)
{
TQString msg = i18n("Could only write %1 bytes of %2.")
- .tqarg(writeLen).tqarg(len);
+ .arg(writeLen).arg(len);
if (aVerbose)
msgDialog(msg);
return FALSE;
@@ -283,7 +283,7 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
if ( !fiToCheck.exists() ) {
error.append( i18n("%1 does not exist")
- .tqarg(toCheck) + "\n");
+ .arg(toCheck) + "\n");
}
// check the access bit of a folder.
@@ -295,7 +295,7 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
if ( !g.isReadable() ) {
if ( chmod( toCheckEnc, statbuffer.st_mode + S_IXUSR ) != 0 ) {
error.append( i18n("%1 is not accessible and that is "
- "unchangeable.").tqarg(toCheck) + "\n");
+ "unchangeable.").arg(toCheck) + "\n");
} else {
kdDebug() << "Changed access bit for " << toCheck << endl;
}
@@ -316,7 +316,7 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
// Lets try changing it.
if ( chmod( toCheckEnc, statbuffer.st_mode + S_IRUSR ) != 0 ) {
error.append( i18n("%1 is not readable and that is unchangeable.")
- .tqarg(toCheck) + "\n");
+ .arg(toCheck) + "\n");
} else {
kdDebug() << "Changed the read bit for " << toCheck << endl;
}
@@ -332,7 +332,7 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
// Lets try changing it.
if ( chmod (toCheckEnc, statbuffer.st_mode + S_IWUSR ) != 0 ) {
error.append( i18n("%1 is not writable and that is unchangeable.")
- .tqarg(toCheck) + "\n");
+ .arg(toCheck) + "\n");
} else {
kdDebug() << "Changed the write bit for " << toCheck << endl;
}
@@ -346,7 +346,7 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
// First check if the folder is readable for us. If not, we get
// some ugly crashes.
if ( !g.isReadable() ){
- error.append(i18n("Folder %1 is inaccessible.").tqarg(toCheck) + "\n");
+ error.append(i18n("Folder %1 is inaccessible.").arg(toCheck) + "\n");
} else {
const TQFileInfoList *list = g.entryInfoList();
TQFileInfoListIterator it( *list );
diff --git a/libtdepim/kfoldertree.cpp b/libtdepim/kfoldertree.cpp
index de29d6a65..79ad6aa9c 100644
--- a/libtdepim/kfoldertree.cpp
+++ b/libtdepim/kfoldertree.cpp
@@ -198,7 +198,7 @@ void KFolderTreeItem::setFolderSize( TQ_INT64 aSize )
TQ_INT64 recursiveSize = recursiveFolderSize();
if ( recursiveSize != mSize ) {
if ( mType != Root )
- size += TQString::fromLatin1(" + %1").tqarg( KIO::convertSize( recursiveSize - mSize ) );
+ size += TQString::fromLatin1(" + %1").arg( KIO::convertSize( recursiveSize - mSize ) );
else
size = KIO::convertSize( recursiveSize );
}
@@ -351,7 +351,7 @@ void KFolderTreeItem::setFolderIsCloseToQuota( bool v )
{
if ( mFolderIsCloseToQuota != v) {
mFolderIsCloseToQuota = v;
- tqrepaint();
+ repaint();
}
}
@@ -535,7 +535,7 @@ void KFolderTree::setFullWidth( bool fullWidth )
//-----------------------------------------------------------------------------
void KFolderTree::slotSizeChanged( int section, int, int newSize )
{
- viewport()->tqrepaint(
+ viewport()->repaint(
header()->sectionPos(section), 0, newSize, visibleHeight(), false );
}
diff --git a/libtdepim/kimportdialog.cpp b/libtdepim/kimportdialog.cpp
index da6c98fad..d7e5675eb 100644
--- a/libtdepim/kimportdialog.cpp
+++ b/libtdepim/kimportdialog.cpp
@@ -337,7 +337,7 @@ void KImportDialog::readFile( int rows )
if (x == mSeparator)
{
progress->setValue(progressValue++);
- if (progressValue % 15 == 0) // try not to constantly tqrepaint
+ if (progressValue % 15 == 0) // try not to constantly repaint
kapp->processEvents();
}
diff --git a/libtdepim/kincidencechooser.cpp b/libtdepim/kincidencechooser.cpp
index fee89bbb6..68ac5854b 100644
--- a/libtdepim/kincidencechooser.cpp
+++ b/libtdepim/kincidencechooser.cpp
@@ -265,9 +265,9 @@ void KIncidenceChooser::showDiff()
}
mDisplayDiff = new KPIM::HTMLDiffAlgoDisplay (this);
if ( mInc1->summary().left( 20 ) != mInc2->summary().left( 20 ) )
- mDisplayDiff->setCaption( i18n( "Differences of %1 and %2").tqarg( mInc1->summary().left( 20 ) ).tqarg( mInc2->summary().left( 20 ) ) );
+ mDisplayDiff->setCaption( i18n( "Differences of %1 and %2").arg( mInc1->summary().left( 20 ) ).arg( mInc2->summary().left( 20 ) ) );
else
- mDisplayDiff->setCaption( i18n( "Differences of %1").tqarg( mInc1->summary().left( 20 ) ) );
+ mDisplayDiff->setCaption( i18n( "Differences of %1").arg( mInc1->summary().left( 20 ) ) );
diff = new KPIM::CalendarDiffAlgo( mInc1, mInc2);
diff->setLeftSourceTitle( i18n( "Local entry"));
diff --git a/libtdepim/komposer/core/pluginmanager.cpp b/libtdepim/komposer/core/pluginmanager.cpp
index 58cffa13d..2a55d7349 100644
--- a/libtdepim/komposer/core/pluginmanager.cpp
+++ b/libtdepim/komposer/core/pluginmanager.cpp
@@ -311,7 +311,7 @@ PluginManager::loadPluginInternal( const TQString &pluginId )
int error = 0;
Plugin *plugin = KParts::ComponentFactory::createInstanceFromQuery<Komposer::Plugin>(
TQString::fromLatin1( "Komposer/Plugin" ),
- TQString::fromLatin1( "[X-KDE-PluginInfo-Name]=='%1'" ).tqarg( pluginId ),
+ TQString::fromLatin1( "[X-KDE-PluginInfo-Name]=='%1'" ).arg( pluginId ),
this, 0, TQStringList(), &error );
if ( plugin ) {
diff --git a/libtdepim/komposer/plugins/default/defaulteditor.cpp b/libtdepim/komposer/plugins/default/defaulteditor.cpp
index 347db891c..105650eb0 100644
--- a/libtdepim/komposer/plugins/default/defaulteditor.cpp
+++ b/libtdepim/komposer/plugins/default/defaulteditor.cpp
@@ -87,7 +87,7 @@ DefaultEditor::changeSignature( const TQString &sig )
TQString text = m_textEdit->text();
int sigStart = text.findRev( "-- " );
- TQString sigText = TQString( "-- \n%1" ).tqarg( sig );
+ TQString sigText = TQString( "-- \n%1" ).arg( sig );
text.replace( sigStart, text.length(), sigText );
}
@@ -202,10 +202,10 @@ DefaultEditor::createActions( KActionCollection *ac )
connect( m_actionAlignJustify, TQT_SIGNAL(toggled(bool)),
this, TQT_SLOT(setAlignJustify(bool)) );
- m_actionAlignLeft->setExclusiveGroup( "tqalignment" );
- m_actionAlignCenter->setExclusiveGroup( "tqalignment" );
- m_actionAlignRight->setExclusiveGroup( "tqalignment" );
- m_actionAlignJustify->setExclusiveGroup( "tqalignment" );
+ m_actionAlignLeft->setExclusiveGroup( "alignment" );
+ m_actionAlignCenter->setExclusiveGroup( "alignment" );
+ m_actionAlignRight->setExclusiveGroup( "alignment" );
+ m_actionAlignJustify->setExclusiveGroup( "alignment" );
//
// Tools
@@ -244,7 +244,7 @@ DefaultEditor::updateCharFmt()
void
DefaultEditor::updateAligment()
{
- int align = m_textEdit->tqalignment();
+ int align = m_textEdit->alignment();
switch ( align ) {
case AlignRight:
diff --git a/libtdepim/komposer/plugins/default/defaulteditorui.rc b/libtdepim/komposer/plugins/default/defaulteditorui.rc
index de8c2e6d2..479fa8b06 100644
--- a/libtdepim/komposer/plugins/default/defaulteditorui.rc
+++ b/libtdepim/komposer/plugins/default/defaulteditorui.rc
@@ -24,7 +24,7 @@
<Action name="format_color"/>
<DefineGroup name="format_chars_group" />
<Separator/>
- <Menu name="tqalignment"><text>&amp;Alignment</text>
+ <Menu name="alignment"><text>&amp;Alignment</text>
<Action name="format_align_left"/>
<Action name="format_align_center"/>
<Action name="format_align_right"/>
diff --git a/libtdepim/kpixmapregionselectorwidget.cpp b/libtdepim/kpixmapregionselectorwidget.cpp
index 04ef9c8f4..0697f667d 100644
--- a/libtdepim/kpixmapregionselectorwidget.cpp
+++ b/libtdepim/kpixmapregionselectorwidget.cpp
@@ -216,7 +216,7 @@ bool KPixmapRegionSelectorWidget::eventFilter(TQObject *obj, TQEvent *ev)
if ( ev->type() == TQEvent::MouseButtonPress )
{
TQMouseEvent *mev= (TQMouseEvent *)(ev);
- //kdDebug() << TQString("click at %1,%2").tqarg( mev->x() ).tqarg( mev->y() ) << endl;
+ //kdDebug() << TQString("click at %1,%2").arg( mev->x() ).arg( mev->y() ) << endl;
if ( mev->button() == Qt::RightButton )
{
@@ -249,7 +249,7 @@ bool KPixmapRegionSelectorWidget::eventFilter(TQObject *obj, TQEvent *ev)
{
TQMouseEvent *mev= (TQMouseEvent *)(ev);
- //kdDebug() << TQString("move to %1,%2").tqarg( mev->x() ).tqarg( mev->y() ) << endl;
+ //kdDebug() << TQString("move to %1,%2").arg( mev->x() ).arg( mev->y() ) << endl;
if ( m_state == Resizing )
{
@@ -421,7 +421,7 @@ void KPixmapRegionSelectorWidget::setMaximumWidgetSize(int width, int height)
if (m_selectedRegion == m_originalPixmap.rect()) m_selectedRegion=TQRect();
// kdDebug() << TQString(" original Pixmap :") << m_originalPixmap.rect() << endl;
-// kdDebug() << TQString(" unzoomed Pixmap : %1 x %2 ").tqarg(m_unzoomedPixmap.width()).tqarg(m_unzoomedPixmap.height()) << endl;
+// kdDebug() << TQString(" unzoomed Pixmap : %1 x %2 ").arg(m_unzoomedPixmap.width()).arg(m_unzoomedPixmap.height()) << endl;
if ( !m_originalPixmap.isNull() &&
( m_originalPixmap.width() > m_maxWidth ||
diff --git a/libtdepim/kregexp3.cpp b/libtdepim/kregexp3.cpp
index bffc491ea..d60946c28 100644
--- a/libtdepim/kregexp3.cpp
+++ b/libtdepim/kregexp3.cpp
@@ -64,7 +64,7 @@ TQString KRegExp3::replace( const TQString & str,
pos = rx.search( replacementStr, pos );
#ifdef DEBUG_KREGEXP3
- kdDebug() << TQString(" Found match at pos %1").tqarg(pos) << endl;
+ kdDebug() << TQString(" Found match at pos %1").arg(pos) << endl;
#endif
if ( pos < 0 ) {
@@ -88,13 +88,13 @@ TQString KRegExp3::replace( const TQString & str,
backRefs << rx.cap(i).toInt();
#ifdef DEBUG_KREGEXP3
kdDebug() << TQString(" Found %1 at position %2 in the capturedTexts.")
- .tqarg(backRefs.last()).tqarg(i) << endl;
+ .arg(backRefs.last()).arg(i) << endl;
#endif
break;
}
pos += rx.matchedLength();
#ifdef DEBUG_KREGEXP3
- kdDebug() << TQString(" Setting new pos to %1.").tqarg(pos) << endl;
+ kdDebug() << TQString(" Setting new pos to %1.").arg(pos) << endl;
#endif
oldpos = pos;
}
@@ -125,7 +125,7 @@ TQString KRegExp3::replace( const TQString & str,
pos = search( str, pos );
#ifdef DEBUG_KREGEXP3
- kdDebug() << TQString(" Found match at pos %1").tqarg(pos) << endl;
+ kdDebug() << TQString(" Found match at pos %1").arg(pos) << endl;
#endif
if ( pos < 0 ) {
@@ -168,7 +168,7 @@ TQString KRegExp3::replace( const TQString & str,
}
pos += matchedLength();
#ifdef DEBUG_KREGEXP3
- kdDebug() << TQString(" Setting new pos to %1.").tqarg(pos) << endl;
+ kdDebug() << TQString(" Setting new pos to %1.").arg(pos) << endl;
#endif
oldpos = pos;
diff --git a/libtdepim/krsqueezedtextlabel.cpp b/libtdepim/krsqueezedtextlabel.cpp
index ad674aa84..d024cd97c 100644
--- a/libtdepim/krsqueezedtextlabel.cpp
+++ b/libtdepim/krsqueezedtextlabel.cpp
@@ -75,11 +75,11 @@ void KRSqueezedTextLabel::squeezeTextToLabel() {
}
}
-void KRSqueezedTextLabel::setAlignment( int tqalignment )
+void KRSqueezedTextLabel::setAlignment( int alignment )
{
// save fullText and restore it
TQString tmpFull(fullText);
- TQLabel::setAlignment(tqalignment);
+ TQLabel::setAlignment(alignment);
fullText = tmpFull;
}
diff --git a/libtdepim/kscoring.cpp b/libtdepim/kscoring.cpp
index e97523772..3bcbd7fd4 100644
--- a/libtdepim/kscoring.cpp
+++ b/libtdepim/kscoring.cpp
@@ -1137,7 +1137,7 @@ TQString KScoringManager::findUniqueName() const
while (nr < 99999999) {
nr++;
- ret = i18n("rule %1").tqarg(nr);
+ ret = i18n("rule %1").arg(nr);
duplicated=false;
TQPtrListIterator<KScoringRule> it(allRules);
diff --git a/libtdepim/ksubscription.cpp b/libtdepim/ksubscription.cpp
index e3c2ce4f4..f1c5b657a 100644
--- a/libtdepim/ksubscription.cpp
+++ b/libtdepim/ksubscription.cpp
@@ -133,7 +133,7 @@ void GroupItem::setVisible( bool b )
TQListViewItem::setVisible(b);
else
{
- // leave it visible so that tqchildren remain visible
+ // leave it visible so that children remain visible
setOpen(true);
setEnabled(false);
}
@@ -775,7 +775,7 @@ void KSubscription::slotUpdateStatusLabel()
activeItemCount());
else
text = i18n("%1: (1 matching)", "%1: (%n matching)", activeItemCount())
- .tqarg(account()->name());
+ .arg(account()->name());
leftLabel->setText(text);
}
diff --git a/libtdepim/ldapclient.cpp b/libtdepim/ldapclient.cpp
index 563728da3..038824cad 100644
--- a/libtdepim/ldapclient.cpp
+++ b/libtdepim/ldapclient.cpp
@@ -49,7 +49,7 @@ static KStaticDeleter<KConfig> configDeleter;
TQString LdapObject::toString() const
{
- TQString result = TQString::fromLatin1( "\ndn: %1\n" ).tqarg( dn );
+ TQString result = TQString::fromLatin1( "\ndn: %1\n" ).arg( dn );
for ( LdapAttrMap::ConstIterator it = attrs.begin(); it != attrs.end(); ++it ) {
TQString attr = it.key();
for ( LdapAttrValue::ConstIterator it2 = (*it).begin(); it2 != (*it).end(); ++it2 ) {
@@ -278,53 +278,53 @@ void LdapSearch::readConfig( LdapServer &server, KConfig *config, int j, bool ac
{
TQString prefix;
if ( active ) prefix = "Selected";
- TQString host = config->readEntry( prefix + TQString( "Host%1" ).tqarg( j ), "" ).stripWhiteSpace();
+ TQString host = config->readEntry( prefix + TQString( "Host%1" ).arg( j ), "" ).stripWhiteSpace();
if ( !host.isEmpty() )
server.setHost( host );
- int port = config->readNumEntry( prefix + TQString( "Port%1" ).tqarg( j ), 389 );
+ int port = config->readNumEntry( prefix + TQString( "Port%1" ).arg( j ), 389 );
server.setPort( port );
- TQString base = config->readEntry( prefix + TQString( "Base%1" ).tqarg( j ), "" ).stripWhiteSpace();
+ TQString base = config->readEntry( prefix + TQString( "Base%1" ).arg( j ), "" ).stripWhiteSpace();
if ( !base.isEmpty() )
server.setBaseDN( base );
- TQString user = config->readEntry( prefix + TQString( "User%1" ).tqarg( j ) ).stripWhiteSpace();
+ TQString user = config->readEntry( prefix + TQString( "User%1" ).arg( j ) ).stripWhiteSpace();
if ( !user.isEmpty() )
server.setUser( user );
- TQString bindDN = config->readEntry( prefix + TQString( "Bind%1" ).tqarg( j ) ).stripWhiteSpace();
+ TQString bindDN = config->readEntry( prefix + TQString( "Bind%1" ).arg( j ) ).stripWhiteSpace();
if ( !bindDN.isEmpty() )
server.setBindDN( bindDN );
- TQString pwdBindDN = config->readEntry( prefix + TQString( "PwdBind%1" ).tqarg( j ) );
+ TQString pwdBindDN = config->readEntry( prefix + TQString( "PwdBind%1" ).arg( j ) );
if ( !pwdBindDN.isEmpty() )
server.setPwdBindDN( pwdBindDN );
- server.setTimeLimit( config->readNumEntry( prefix + TQString( "TimeLimit%1" ).tqarg( j ) ) );
- server.setSizeLimit( config->readNumEntry( prefix + TQString( "SizeLimit%1" ).tqarg( j ) ) );
- server.setVersion( config->readNumEntry( prefix + TQString( "Version%1" ).tqarg( j ), 3 ) );
- server.setSecurity( config->readNumEntry( prefix + TQString( "Security%1" ).tqarg( j ) ) );
- server.setAuth( config->readNumEntry( prefix + TQString( "Auth%1" ).tqarg( j ) ) );
- server.setMech( config->readEntry( prefix + TQString( "Mech%1" ).tqarg( j ) ) );
+ server.setTimeLimit( config->readNumEntry( prefix + TQString( "TimeLimit%1" ).arg( j ) ) );
+ server.setSizeLimit( config->readNumEntry( prefix + TQString( "SizeLimit%1" ).arg( j ) ) );
+ server.setVersion( config->readNumEntry( prefix + TQString( "Version%1" ).arg( j ), 3 ) );
+ server.setSecurity( config->readNumEntry( prefix + TQString( "Security%1" ).arg( j ) ) );
+ server.setAuth( config->readNumEntry( prefix + TQString( "Auth%1" ).arg( j ) ) );
+ server.setMech( config->readEntry( prefix + TQString( "Mech%1" ).arg( j ) ) );
}
void LdapSearch::writeConfig( const LdapServer &server, KConfig *config, int j, bool active )
{
TQString prefix;
if ( active ) prefix = "Selected";
- config->writeEntry( prefix + TQString( "Host%1" ).tqarg( j ), server.host() );
- config->writeEntry( prefix + TQString( "Port%1" ).tqarg( j ), server.port() );
- config->writeEntry( prefix + TQString( "Base%1" ).tqarg( j ), server.baseDN() );
- config->writeEntry( prefix + TQString( "User%1" ).tqarg( j ), server.user() );
- config->writeEntry( prefix + TQString( "Bind%1" ).tqarg( j ), server.bindDN() );
- config->writeEntry( prefix + TQString( "PwdBind%1" ).tqarg( j ), server.pwdBindDN() );
- config->writeEntry( prefix + TQString( "TimeLimit%1" ).tqarg( j ), server.timeLimit() );
- config->writeEntry( prefix + TQString( "SizeLimit%1" ).tqarg( j ), server.sizeLimit() );
- config->writeEntry( prefix + TQString( "Version%1" ).tqarg( j ), server.version() );
- config->writeEntry( prefix + TQString( "Security%1" ).tqarg( j ), server.security() );
- config->writeEntry( prefix + TQString( "Auth%1" ).tqarg( j ), server.auth() );
- config->writeEntry( prefix + TQString( "Mech%1" ).tqarg( j ), server.mech() );
+ config->writeEntry( prefix + TQString( "Host%1" ).arg( j ), server.host() );
+ config->writeEntry( prefix + TQString( "Port%1" ).arg( j ), server.port() );
+ config->writeEntry( prefix + TQString( "Base%1" ).arg( j ), server.baseDN() );
+ config->writeEntry( prefix + TQString( "User%1" ).arg( j ), server.user() );
+ config->writeEntry( prefix + TQString( "Bind%1" ).arg( j ), server.bindDN() );
+ config->writeEntry( prefix + TQString( "PwdBind%1" ).arg( j ), server.pwdBindDN() );
+ config->writeEntry( prefix + TQString( "TimeLimit%1" ).arg( j ), server.timeLimit() );
+ config->writeEntry( prefix + TQString( "SizeLimit%1" ).arg( j ), server.sizeLimit() );
+ config->writeEntry( prefix + TQString( "Version%1" ).arg( j ), server.version() );
+ config->writeEntry( prefix + TQString( "Security%1" ).arg( j ), server.security() );
+ config->writeEntry( prefix + TQString( "Auth%1" ).arg( j ), server.auth() );
+ config->writeEntry( prefix + TQString( "Mech%1" ).arg( j ), server.mech() );
}
KConfig* LdapSearch::config()
@@ -351,7 +351,7 @@ LdapSearch::LdapSearch()
void LdapSearch::readWeighForClient( LdapClient *client, KConfig *config, int clientNumber )
{
- const int completionWeight = config->readNumEntry( TQString( "SelectedCompletionWeight%1" ).tqarg( clientNumber ), -1 );
+ const int completionWeight = config->readNumEntry( TQString( "SelectedCompletionWeight%1" ).arg( clientNumber ), -1 );
if ( completionWeight != -1 )
client->setCompletionWeight( completionWeight );
}
@@ -442,7 +442,7 @@ void LdapSearch::startSearch( const TQString& txt )
* person entries without an email address to show up, while still not showing things
* like structural entries in the ldap tree. */
TQString filter = TQString( "&(|(objectclass=person)(objectclass=groupOfNames)(mail=*))(|(cn=%1*)(mail=%2*)(mail=*@%3*)(givenName=%4*)(sn=%5*))" )
- .tqarg( mSearchText ).tqarg( mSearchText ).tqarg( mSearchText ).tqarg( mSearchText ).tqarg( mSearchText );
+ .arg( mSearchText ).arg( mSearchText ).arg( mSearchText ).arg( mSearchText ).arg( mSearchText );
TQValueList< LdapClient* >::Iterator it;
for ( it = mClients.begin(); it != mClients.end(); ++it ) {
@@ -590,7 +590,7 @@ void LdapSearch::makeSearchData( TQStringList& ret, LdapResultList& resList )
ret.append( mail );
} else {
//kdDebug(5300) << "LdapSearch::makeSearchData() name: \"" << name << "\" mail: \"" << mail << "\"" << endl;
- ret.append( TQString( "%1 <%2>" ).tqarg( name ).tqarg( mail ) );
+ ret.append( TQString( "%1 <%2>" ).arg( name ).arg( mail ) );
}
LdapResult sr;
diff --git a/libtdepim/ldapsearchdialog.cpp b/libtdepim/ldapsearchdialog.cpp
index 0f991686c..941253a45 100644
--- a/libtdepim/ldapsearchdialog.cpp
+++ b/libtdepim/ldapsearchdialog.cpp
@@ -238,23 +238,23 @@ void LDAPSearchDialog::restoreSettings()
for ( int j = 0; j < mNumHosts; ++j ) {
KPIM::LdapServer ldapServer;
- TQString host = config->readEntry( TQString( "SelectedHost%1" ).tqarg( j ), "" );
+ TQString host = config->readEntry( TQString( "SelectedHost%1" ).arg( j ), "" );
if ( !host.isEmpty() )
ldapServer.setHost( host );
- int port = config->readUnsignedNumEntry( TQString( "SelectedPort%1" ).tqarg( j ) );
+ int port = config->readUnsignedNumEntry( TQString( "SelectedPort%1" ).arg( j ) );
if ( port )
ldapServer.setPort( port );
- TQString base = config->readEntry( TQString( "SelectedBase%1" ).tqarg( j ), "" );
+ TQString base = config->readEntry( TQString( "SelectedBase%1" ).arg( j ), "" );
if ( !base.isEmpty() )
ldapServer.setBaseDN( base );
- TQString bindDN = config->readEntry( TQString( "SelectedBind%1" ).tqarg( j ), "" );
+ TQString bindDN = config->readEntry( TQString( "SelectedBind%1" ).arg( j ), "" );
if ( !bindDN.isEmpty() )
ldapServer.setBindDN( bindDN );
- TQString pwdBindDN = config->readEntry( TQString( "SelectedPwdBind%1" ).tqarg( j ), "" );
+ TQString pwdBindDN = config->readEntry( TQString( "SelectedPwdBind%1" ).arg( j ), "" );
if ( !pwdBindDN.isEmpty() )
ldapServer.setPwdBindDN( pwdBindDN );
@@ -352,15 +352,15 @@ TQString LDAPSearchDialog::makeFilter( const TQString& query, const TQString& at
if ( attr == i18n( "Name" ) ) {
result += startsWith ? "|(cn=%1*)(sn=%2*)" : "|(cn=*%1*)(sn=*%2*)";
- result = result.tqarg( query ).tqarg( query );
+ result = result.arg( query ).arg( query );
} else {
result += (startsWith ? "%1=%2*" : "%1=*%2*");
if ( attr == i18n( "Email" ) ) {
- result = result.tqarg( "mail" ).tqarg( query );
+ result = result.arg( "mail" ).arg( query );
} else if ( attr == i18n( "Home Number" ) ) {
- result = result.tqarg( "homePhone" ).tqarg( query );
+ result = result.arg( "homePhone" ).arg( query );
} else if ( attr == i18n( "Work Number" ) ) {
- result = result.tqarg( "telephoneNumber" ).tqarg( query );
+ result = result.arg( "telephoneNumber" ).arg( query );
} else {
// Error?
result = TQString();
diff --git a/libtdepim/linklocator.cpp b/libtdepim/linklocator.cpp
index 25a5a6644..8738788f4 100644
--- a/libtdepim/linklocator.cpp
+++ b/libtdepim/linklocator.cpp
@@ -362,7 +362,7 @@ TQString LinkLocator::pngToDataUrl( const TQString & iconPath )
TQByteArray ba = pngFile.readAll();
pngFile.close();
return TQString::fromLatin1("data:image/png;base64,%1")
- .tqarg( KCodecs::base64Encode( ba ).data() );
+ .arg( KCodecs::base64Encode( ba ).data() );
}
@@ -422,7 +422,7 @@ TQString LinkLocator::getEmoticon()
// for copy & paste) representing the smiley
htmlRep = TQString("<img class=\"pimsmileyimg\" src=\"%1\" "
"alt=\"%2\" title=\"%3\" width=\"16\" height=\"16\"/>")
- .tqarg( dataUrl,
+ .arg( dataUrl,
TQStyleSheet::escape( smiley ),
TQStyleSheet::escape( smiley ) );
}
@@ -445,7 +445,7 @@ TQString LinkLocator::highlightedText()
if ( ch != '/' && ch != '*' && ch != '_' )
return TQString();
- TQRegExp re = TQRegExp( TQString("\\%1([0-9A-Za-z]+)\\%2").tqarg( ch ).tqarg( ch ) );
+ TQRegExp re = TQRegExp( TQString("\\%1([0-9A-Za-z]+)\\%2").arg( ch ).arg( ch ) );
if ( re.search( mText, mPos ) == mPos ) {
uint length = re.matchedLength();
// there must be a whitespace after the closing formating symbol
diff --git a/libtdepim/overlaywidget.h b/libtdepim/overlaywidget.h
index 9e611fb92..1ad9dfa36 100644
--- a/libtdepim/overlaywidget.h
+++ b/libtdepim/overlaywidget.h
@@ -37,7 +37,7 @@ namespace KPIM {
/**
* This is a widget that can align itself with another one, without using a tqlayout,
* so that it can actually be on top of other widgets.
- * Currently the only supported type of tqalignment is "right aligned, on top of the other widget".
+ * Currently the only supported type of alignment is "right aligned, on top of the other widget".
*
* OverlayWidget inherits TQHBox for convenience purposes (tqlayout, and frame)
*/
diff --git a/libtdepim/progressdialog.cpp b/libtdepim/progressdialog.cpp
index b5b6c6ce3..b9e196143 100644
--- a/libtdepim/progressdialog.cpp
+++ b/libtdepim/progressdialog.cpp
@@ -209,7 +209,7 @@ void TransactionItem::setLabel( const TQString& label )
mItemLabel->setText( label );
}
-void TransactionItem::seStatus( const TQString& status )
+void TransactionItem::setStatus( const TQString& status )
{
mItemStatus->setText( status );
}
@@ -358,7 +358,7 @@ void ProgressDialog::slotTransactionStatus( ProgressItem *item,
{
if ( mTransactionsToListviewItems.contains( item ) ) {
TransactionItem *ti = mTransactionsToListviewItems[ item ];
- ti->seStatus( status );
+ ti->setStatus( status );
}
}
diff --git a/libtdepim/progressdialog.h b/libtdepim/progressdialog.h
index e144e34eb..91d92be57 100644
--- a/libtdepim/progressdialog.h
+++ b/libtdepim/progressdialog.h
@@ -90,7 +90,7 @@ public:
void setProgress( int progress );
void setLabel( const TQString& );
- void seStatus( const TQString& );
+ void setStatus( const TQString& );
void setCrypto( bool );
void setTotalSteps( int totalSteps );
diff --git a/libtdepim/progressmanager.cpp b/libtdepim/progressmanager.cpp
index 2c6e1a3cf..0f3e39cae 100644
--- a/libtdepim/progressmanager.cpp
+++ b/libtdepim/progressmanager.cpp
@@ -84,7 +84,7 @@ void ProgressItem::cancel()
if ( mCanceled || !mCanBeCanceled ) return;
kdDebug(5300) << "ProgressItem::cancel() - " << label() << endl;
mCanceled = true;
- // Cancel all tqchildren.
+ // Cancel all children.
TQValueList<ProgressItem*> kids = mChildren.keys();
TQValueList<ProgressItem*>::Iterator it( kids.begin() );
TQValueList<ProgressItem*>::Iterator end( kids.end() );
@@ -93,7 +93,7 @@ void ProgressItem::cancel()
if ( kid->canBeCanceled() )
kid->cancel();
}
- seStatus( i18n( "Aborting..." ) );
+ setStatus( i18n( "Aborting..." ) );
emit progressItemCanceled( this );
}
@@ -111,7 +111,7 @@ void ProgressItem::setLabel( const TQString& v )
emit progressItemLabel( this, mLabel );
}
-void ProgressItem::seStatus( const TQString& v )
+void ProgressItem::setStatus( const TQString& v )
{
mStatus = v;
emit progressItemStatus( this, mStatus );
diff --git a/libtdepim/progressmanager.h b/libtdepim/progressmanager.h
index bb8e864ad..2458d5ca0 100644
--- a/libtdepim/progressmanager.h
+++ b/libtdepim/progressmanager.h
@@ -76,7 +76,7 @@ class KDE_EXPORT ProgressItem : public TQObject
* @p v will be interpreted as rich text, so it might have to be escaped.
* @param v The status string.
*/
- void seStatus( const TQString& v );
+ void setStatus( const TQString& v );
/**
* @return Whether this item can be cancelled.
@@ -132,7 +132,7 @@ class KDE_EXPORT ProgressItem : public TQObject
* Reset the progress value of this item to 0 and the status string to
* the empty string.
*/
- void reset() { setProgress( 0 ); seStatus( TQString() ); mCompleted = 0; }
+ void reset() { setProgress( 0 ); setStatus( TQString() ); mCompleted = 0; }
void cancel();
@@ -310,8 +310,8 @@ class KDE_EXPORT ProgressManager : public TQObject
* interpreted as rich text, so it might have to be escaped.
* @param canBeCanceled can the user cancel this operation?
* @param usesCrypto does the operation use secure transports (SSL)
- * Cancelling the parent will cancel the tqchildren as well (if they can be
- * cancelled) and ongoing tqchildren prevent parents from finishing.
+ * Cancelling the parent will cancel the children as well (if they can be
+ * cancelled) and ongoing children prevent parents from finishing.
* @return The ProgressItem representing the operation.
*/
static ProgressItem * createProgressItem( ProgressItem* parent,
@@ -360,7 +360,7 @@ class KDE_EXPORT ProgressManager : public TQObject
* @return the only top level progressitem when there's only one.
* Returns 0 if there is no item, or more than one top level item.
* Since this is used to calculate the overall progress, it will also return
- * 0 if there is an item which uses a busy indicator, since that will tqinvalidate
+ * 0 if there is an item which uses a busy indicator, since that will invalidate
* the overall progress.
*/
ProgressItem* singleItem() const;
diff --git a/libtdepim/qutf7codec.cpp b/libtdepim/qutf7codec.cpp
index dc8ef2a2f..b0076172c 100644
--- a/libtdepim/qutf7codec.cpp
+++ b/libtdepim/qutf7codec.cpp
@@ -18,7 +18,7 @@
with any version of TQt by TrollTech AS, Norway. In this case, the
use of this plugin doesn't cause the resulting executable to be
covered by the GNU General Public License.
- This exception does not however tqinvalidate any other reasons why the
+ This exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License.
*/
diff --git a/libtdepim/qutf7codec.h b/libtdepim/qutf7codec.h
index 4057d276c..ef7000ff4 100644
--- a/libtdepim/qutf7codec.h
+++ b/libtdepim/qutf7codec.h
@@ -18,7 +18,7 @@
with any version of TQt by TrollTech AS, Norway. In this case, the
use of this plugin doesn't cause the resulting executable to be
covered by the GNU General Public License.
- This exception does not however tqinvalidate any other reasons why the
+ This exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License.
*/
diff --git a/libtdepim/qutf7codecplugin.cpp b/libtdepim/qutf7codecplugin.cpp
index 49eb92c8f..7702ed9f1 100644
--- a/libtdepim/qutf7codecplugin.cpp
+++ b/libtdepim/qutf7codecplugin.cpp
@@ -18,7 +18,7 @@
with any version of TQt by TrollTech AS, Norway. In this case, the
use of this plugin doesn't cause the resulting executable to be
covered by the GNU General Public License.
- This exception does not however tqinvalidate any other reasons why the
+ This exception does not however invalidate any other reasons why the
executable file might be covered by the GNU General Public License.
*/
diff --git a/libtdepim/sendsmsdialog.cpp b/libtdepim/sendsmsdialog.cpp
index d7ffd57c8..0232a7823 100644
--- a/libtdepim/sendsmsdialog.cpp
+++ b/libtdepim/sendsmsdialog.cpp
@@ -68,13 +68,13 @@ void SendSMSDialog::updateMessageLength()
int length = mText->length();
if( length > 480 )
- mMessageLength->setText( TQString( "%1/%2 (%3)" ).tqarg( length ).tqarg( 500 ).tqarg( 4 ) );
+ mMessageLength->setText( TQString( "%1/%2 (%3)" ).arg( length ).arg( 500 ).arg( 4 ) );
else if( length > 320 )
- mMessageLength->setText( TQString( "%1/%2 (%3)" ).tqarg( length ).tqarg( 480 ).tqarg( 3 ) );
+ mMessageLength->setText( TQString( "%1/%2 (%3)" ).arg( length ).arg( 480 ).arg( 3 ) );
else if( length > 160 )
- mMessageLength->setText( TQString( "%1/%2 (%3)" ).tqarg( length ).tqarg( 320 ).tqarg( 2 ) );
+ mMessageLength->setText( TQString( "%1/%2 (%3)" ).arg( length ).arg( 320 ).arg( 2 ) );
else
- mMessageLength->setText( TQString( "%1/%2" ).tqarg( length ).tqarg( 160 ) );
+ mMessageLength->setText( TQString( "%1/%2" ).arg( length ).arg( 160 ) );
}
void SendSMSDialog::updateButtons()
diff --git a/libtdepim/addresseeview.cpp b/libtdepim/addresseeview.cpp
index 23f01eb5e..b3bccffad 100644
--- a/libtdepim/addresseeview.cpp
+++ b/libtdepim/addresseeview.cpp
@@ -151,11 +151,11 @@ void AddresseeView::enableLinks( int linkMask )
TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *proxy, LinkMask linkMask,
bool internalLoading, FieldMask fieldMask )
{
- TQString image = TQString( "contact_%1_image" ).tqarg( addr.uid() );
+ TQString image = TQString( "contact_%1_image" ).arg( addr.uid() );
// Style strings from Gentix; this is just an initial version.
//
// These will be substituted into various HTML strings with .tqarg().
// Search for @STYLE@ to find where. Note how we use %1 as a
// placeholder where we fill in something else (in this case,
// the global background color).
@@ -165,12 +165,12 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
"style=\""
"padding-right: 2px; "
"border-right: #000 dashed 1px; "
- "background: %1;\"").tqarg(backgroundColor);
+ "background: %1;\"").arg(backgroundColor);
TQString backgroundColor2 = KGlobalSettings::baseColor().name();
TQString cellStyle2 = TQString::fromLatin1(
"style=\""
"padding-left: 2px; "
- "background: %1;\"").tqarg(backgroundColor2);
+ "background: %1;\"").arg(backgroundColor2);
TQString tableStyle = TQString::fromLatin1(
"style=\""
"border: solid 1px; "
@@ -216,8 +216,8 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( date.isValid() )
dynamicPart += rowFmtStr
- .tqarg( KABC::Addressee::birthdayLabel() )
- .tqarg( KGlobal::locale()->formatDate( date, true ) );
+ .arg( KABC::Addressee::birthdayLabel() )
+ .arg( KGlobal::locale()->formatDate( date, true ) );
}
if ( fieldMask & PhoneFields ) {
@@ -235,15 +235,15 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( linkMask & PhoneLinks ) {
TQString smsURL;
if ( (*phoneIt).type() & KABC::PhoneNumber::Cell )
- smsURL = TQString(" (<a href=\"sms:%1\">%2</a>)" ).tqarg( number ).tqarg( i18n( "SMS") );
+ smsURL = TQString(" (<a href=\"sms:%1\">%2</a>)" ).arg( number ).arg( i18n( "SMS") );
dynamicPart += rowFmtStr
- .tqarg( (*phoneIt).typeLabel().replace( " ", "&nbsp;" ) )
- .tqarg( TQString::fromLatin1( "<a href=\"%1\">%2</a>%3" ).tqarg( url ).tqarg( number ).tqarg( smsURL ) );
+ .arg( (*phoneIt).typeLabel().replace( " ", "&nbsp;" ) )
+ .arg( TQString::fromLatin1( "<a href=\"%1\">%2</a>%3" ).arg( url ).arg( number ).arg( smsURL ) );
} else {
dynamicPart += rowFmtStr
- .tqarg( (*phoneIt).typeLabel().replace( " ", "&nbsp;" ) )
- .tqarg( number );
+ .arg( (*phoneIt).typeLabel().replace( " ", "&nbsp;" ) )
+ .arg( number );
}
}
}
@@ -257,11 +257,11 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
TQUrl::encode( fullEmail );
if ( linkMask & EmailLinks ) {
- dynamicPart += rowFmtStr.tqarg( type )
- .tqarg( TQString::fromLatin1( "<a href=\"mailto:%1\">%2</a>" )
- .tqarg( fullEmail, TQStyleSheet::escape( *emailIt ) ) );
+ dynamicPart += rowFmtStr.arg( type )
+ .arg( TQString::fromLatin1( "<a href=\"mailto:%1\">%2</a>" )
+ .arg( fullEmail, TQStyleSheet::escape( *emailIt ) ) );
} else {
- dynamicPart += rowFmtStr.tqarg( type ).tqarg( *emailIt );
+ dynamicPart += rowFmtStr.arg( type ).arg( *emailIt );
}
}
}
@@ -276,7 +276,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
} else {
url = addr.url().prettyURL();
}
- dynamicPart += rowFmtStr.tqarg( i18n("Homepage") ).tqarg( url );
+ dynamicPart += rowFmtStr.arg( i18n("Homepage") ).arg( url );
}
TQString blog = addr.custom( "KADDRESSBOOK", "BlogFeed" );
@@ -284,7 +284,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( linkMask & URLLinks ) {
blog = KStringHandler::tagURLs( blog );
}
- dynamicPart += rowFmtStr.tqarg( i18n("Blog Feed") ).tqarg( blog );
+ dynamicPart += rowFmtStr.arg( i18n("Blog Feed") ).arg( blog );
}
}
@@ -303,12 +303,12 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( linkMask & AddressLinks ) {
dynamicPart += rowFmtStr
- .tqarg( KABC::Address::typeLabel( (*addrIt).type() ) )
- .tqarg( link );
+ .arg( KABC::Address::typeLabel( (*addrIt).type() ) )
+ .arg( link );
} else {
dynamicPart += rowFmtStr
- .tqarg( KABC::Address::typeLabel( (*addrIt).type() ) )
- .tqarg( formattedAddress );
+ .arg( KABC::Address::typeLabel( (*addrIt).type() ) )
+ .arg( formattedAddress );
}
} else {
TQString link = "<a href=\"addr:" + (*addrIt).id() + "\">" +
@@ -316,12 +316,12 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( linkMask & AddressLinks ) {
dynamicPart += rowFmtStr
- .tqarg( KABC::Address::typeLabel( (*addrIt).type() ) )
- .tqarg( link );
+ .arg( KABC::Address::typeLabel( (*addrIt).type() ) )
+ .arg( link );
} else {
dynamicPart += rowFmtStr
- .tqarg( KABC::Address::typeLabel( (*addrIt).type() ) )
- .tqarg( (*addrIt).label().replace( '\n', "<br>" ) );
+ .arg( KABC::Address::typeLabel( (*addrIt).type() ) )
+ .arg( (*addrIt).label().replace( '\n', "<br>" ) );
}
}
}
@@ -333,7 +333,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
// the data afterwards (keeps us safe from possible % signs
// in either one).
notes = TQStyleSheet::escape( addr.note() );
- notes = rowFmtStr.tqarg( i18n( "Notes" ) ).tqarg( notes.replace( '\n', "<br>" ) ) ;
+ notes = rowFmtStr.arg( i18n( "Notes" ) ).arg( notes.replace( '\n', "<br>" ) ) ;
}
TQString customData;
@@ -371,7 +371,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( keyIt != titleMap.end() )
key = keyIt.data();
- customData += rowFmtStr.tqarg( key ).tqarg( TQStyleSheet::escape( value ) ) ;
+ customData += rowFmtStr.arg( key ).arg( TQStyleSheet::escape( value ) ) ;
}
}
}
@@ -385,7 +385,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
const TQString imAddress = addr.custom( "KADDRESSBOOK", "X-IMAddress" );
if ( !imAddress.isEmpty() ) {
- customData += rowFmtStr.tqarg( i18n( "IM Address" ) ).tqarg( TQStyleSheet::escape( imAddress ) ) ;
+ customData += rowFmtStr.arg( i18n( "IM Address" ) ).arg( TQStyleSheet::escape( imAddress ) ) ;
}
if ( proxy ) {
@@ -393,7 +393,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
// set image source to either a TQMimeSourceFactory key or a data:/ URL
TQString imgSrc;
if ( internalLoading ) {
- imgSrc = TQString::fromLatin1( "im_status_%1_image").tqarg( addr.uid() );
+ imgSrc = TQString::fromLatin1( "im_status_%1_image").arg( addr.uid() );
TQMimeSourceFactory::defaultFactory()->setPixmap( imgSrc, proxy->presenceIcon( addr.uid() ) );
} else
imgSrc = pixmapAsDataUrl( proxy->presenceIcon( addr.uid() ) );
@@ -407,10 +407,10 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
// append our status to the rest of the dynamic part of the addressee
dynamicPart += rowFmtStr
- .tqarg( i18n( "Presence" ) )
- .tqarg( imStatus
- .tqarg( imgSrc )
- .tqarg( proxy->presenceString( addr.uid() ) )
+ .arg( i18n( "Presence" ) )
+ .arg( imStatus
+ .arg( imgSrc )
+ .arg( proxy->presenceString( addr.uid() ) )
);
}
}
@@ -424,44 +424,44 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
TQString strAddr = TQString::fromLatin1(
"<div align=\"center\">"
"<table cellpadding=\"1\" cellspacing=\"0\" %1>"
- "<tr>").tqarg(tableStyle);
+ "<tr>").arg(tableStyle);
strAddr.append( TQString::fromLatin1(
"<td align=\"right\" valign=\"top\" width=\"30%\" rowspan=\"3\" %2>")
- .tqarg( cellStyle ) );
+ .arg( cellStyle ) );
strAddr.append( TQString::fromLatin1(
"<img src=\"%1\" width=\"50\" vspace=\"1\">" // image
"</td>")
- .tqarg( image ) );
+ .arg( image ) );
strAddr.append( TQString::fromLatin1(
"<td align=\"left\" width=\"70%\" %2>")
- .tqarg( cellStyle2 ) );
+ .arg( cellStyle2 ) );
strAddr.append( TQString::fromLatin1(
"<font size=\"+2\"><b>%2</b></font></td>" // name
"</tr>")
- .tqarg( name ) );
+ .arg( name ) );
strAddr.append( TQString::fromLatin1(
"<tr>"
"<td align=\"left\" width=\"70%\" %2>")
- .tqarg( cellStyle2 ) );
+ .arg( cellStyle2 ) );
strAddr.append( TQString::fromLatin1(
"%3</td>" // role
"</tr>")
- .tqarg( role ) );
+ .arg( role ) );
strAddr.append( TQString::fromLatin1(
"<tr>"
"<td align=\"left\" width=\"70%\" %2>")
- .tqarg( cellStyle2 ) );
+ .arg( cellStyle2 ) );
strAddr.append( TQString::fromLatin1(
"%4</td>" // organization
"</tr>")
- .tqarg( organization ) );
+ .arg( organization ) );
strAddr.append( TQString::fromLatin1(
"<tr><td %2>")
- .tqarg( cellStyle ) );
+ .arg( cellStyle ) );
strAddr.append( TQString::fromLatin1(
"&nbsp;</td><td %2>&nbsp;</td></tr>")
- .tqarg( cellStyle2 ) );
+ .arg( cellStyle2 ) );
strAddr.append( dynamicPart );
strAddr.append( notes );
strAddr.append( customData );
@@ -476,7 +476,7 @@ TQString AddresseeView::vCardAsHTML( const KABC::Addressee& addr, ::KIMProxy *pr
if ( !label.isEmpty() )
addrBookName = label;
}
- strAddr.append( i18n( "<p><b>Address book</b>: %1</p>" ).tqarg( addrBookName ) );
+ strAddr.append( i18n( "<p><b>Address book</b>: %1</p>" ).arg( addrBookName ) );
}
return strAddr;
}
@@ -532,11 +532,11 @@ void AddresseeView::updateView()
"%3" // dynamic part
"</body>"
"</html>" )
- .tqarg( KGlobalSettings::textColor().name() )
- .tqarg( KGlobalSettings::baseColor().name() )
- .tqarg( strAddr );
+ .arg( KGlobalSettings::textColor().name() )
+ .arg( KGlobalSettings::baseColor().name() )
+ .arg( strAddr );
- TQString imageURL = TQString( "contact_%1_image" ).tqarg( mAddressee.uid() );
+ TQString imageURL = TQString( "contact_%1_image" ).arg( mAddressee.uid() );
KABC::Picture picture = mAddressee.photo();
if ( picture.isIntern() && !picture.data().isNull() )
@@ -690,27 +690,27 @@ void AddresseeView::slotHighlighted( const TQString &link )
TQString email = link.mid( 7 );
emit emailHighlighted( email );
- emit highlightedMessage( i18n( "Send mail to '%1'" ).tqarg( email ) );
+ emit highlightedMessage( i18n( "Send mail to '%1'" ).arg( email ) );
} else if ( link.startsWith( "phone:" ) ) {
TQString number = link.mid( 8 );
emit phoneNumberHighlighted( strippedNumber( number ) );
- emit highlightedMessage( i18n( "Call number %1" ).tqarg( number ) );
+ emit highlightedMessage( i18n( "Call number %1" ).arg( number ) );
} else if ( link.startsWith( "fax:" ) ) {
TQString number = link.mid( 6 );
emit faxNumberHighlighted( strippedNumber( number ) );
- emit highlightedMessage( i18n( "Send fax to %1" ).tqarg( number ) );
+ emit highlightedMessage( i18n( "Send fax to %1" ).arg( number ) );
} else if ( link.startsWith( "addr:" ) ) {
emit highlightedMessage( i18n( "Show address on map" ) );
} else if ( link.startsWith( "sms:" ) ) {
TQString number = link.mid( 6 );
- emit highlightedMessage( i18n( "Send SMS to %1" ).tqarg( number ) );
+ emit highlightedMessage( i18n( "Send SMS to %1" ).arg( number ) );
} else if ( link.startsWith( "http:" ) || link.startsWith( "https:" ) ) {
emit urlHighlighted( link );
- emit highlightedMessage( i18n( "Open URL %1" ).tqarg( link ) );
+ emit highlightedMessage( i18n( "Open URL %1" ).arg( link ) );
} else if ( link.startsWith( "im:" ) ) {
- emit highlightedMessage( i18n( "Chat with %1" ).tqarg( mAddressee.realName() ) );
+ emit highlightedMessage( i18n( "Chat with %1" ).arg( mAddressee.realName() ) );
} else
emit highlightedMessage( "" );
}
@@ -151,11 +151,11 @@ void AddresseeView::enableLinks( int linkMask )
// Style strings from Gentix; this is just an initial version.
//
- // These will be substituted into various HTML strings with .tqarg().
+ // These will be substituted into various HTML strings with .arg().
// Search for @STYLE@ to find where. Note how we use %1 as a
// placeholder where we fill in something else (in this case,
diff --git a/libtdepim/broadcaststatus.h b/libtdepim/broadcaststatus.h
index 9173feaad..934d1cfa8 100644
--- a/libtdepim/broadcaststatus.h
+++ b/libtdepim/broadcaststatus.h
@@ -41,18 +41,18 @@ public:
/** Return the instance of the singleton object for this class */
static BroadcastStatus *instance();
/** Return the last status message from seStatusMsg() */
TQString statusMsg() const { return mStatusMsg; }
/** Sets a status bar message with timestamp */
- void seStatusMsgWithTimestamp( const TQString& message );
+ void setStatusMsgWithTimestamp( const TQString& message );
/** Sets a transmission completed status bar message */
- void seStatusMsgTransmissionCompleted( int numMessages,
+ void setStatusMsgTransmissionCompleted( int numMessages,
int numBytes = -1,
int numBytesRead = -1,
int numBytesToRead = -1,
bool mLeaveOnServer = false,
KPIM::ProgressItem* progressItem = 0 ); // set the same status in this progress item
- void seStatusMsgTransmissionCompleted( const TQString& account,
+ void setStatusMsgTransmissionCompleted( const TQString& account,
int numMessages,
int numBytes = -1,
int numBytesRead = -1,
@@ -63,7 +63,7 @@ public:
public slots:
/** Emit an update status bar signal. It's a slot so it can be hooked up
to other signals. */
- void seStatusMsg( const TQString& message );
+ void setStatusMsg( const TQString& message );
/**
Set a status message that will go away again with the next call of
@@ -78,7 +78,7 @@ public slots:
signals:
/** Emitted when seStatusMsg is called. */
void statusMsg( const TQString& );
protected:
@@ -41,18 +41,18 @@ public:
/** Return the instance of the singleton object for this class */
static BroadcastStatus *instance();
- /** Return the last status message from seStatusMsg() */
+ /** Return the last status message from setStatusMsg() */
TQString statusMsg() const { return mStatusMsg; }
/** Sets a status bar message with timestamp */
@@ -78,7 +78,7 @@ public slots:
signals:
- /** Emitted when seStatusMsg is called. */
+ /** Emitted when setStatusMsg is called. */
void statusMsg( const TQString& );
protected: